@@ -1,13 +1,35 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * DEBUG: section 42    ICMP Pinger program
+ * AUTHOR: Duane Wessels
+ *
+ * SQUID Web Proxy Cache          http://www.squid-cache.org/
+ * ----------------------------------------------------------
+ *
+ *  Squid is the result of efforts by numerous individuals from
+ *  the Internet community; see the CONTRIBUTORS file for full
+ *  details.   Many organizations have provided support for Squid's
+ *  development; see the SPONSORS file for full details.  Squid is
+ *  Copyrighted (C) 2001 by the Regents of the University of
+ *  California; see the COPYRIGHT file for full details.  Squid
+ *  incorporates software developed and/or copyrighted by other
+ *  sources; see the CREDITS file for full details.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  *
- * Squid software is distributed under GPLv2+ license and includes
- * contributions from numerous individuals and organizations.
- * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
-/* DEBUG: section 42    ICMP Pinger program */
-
 #define SQUID_HELPER 1
 
 /**
@@ -82,9 +104,9 @@ Win32__WSAFDIsSet(int fd, fd_set FAR * set)
 #define PINGER_TIMEOUT 10
 
 /* non-windows use STDOUT for feedback to squid */
-#define LINK_TO_SQUID   1
+#define LINK_TO_SQUID	1
 
-#endif  /* _SQUID_WINDOWS_ */
+#endif	/* _SQUID_WINDOWS_ */
 
 // ICMP Engines are declared global here so they can call each other easily.
 IcmpPinger control;
@@ -162,46 +184,18 @@ main(int argc, char *argv[])
     max_fd = max(max_fd, squid_link);
 
     if (setgid(getgid()) < 0) {
-        int xerrno = errno;
-        debugs(42, DBG_CRITICAL, "FATAL: pinger: setgid(" << getgid() << ") failed: " << xstrerr(xerrno));
+        debugs(42, DBG_CRITICAL, "FATAL: pinger: setgid(" << getgid() << ") failed: " << xstrerror());
         icmp4.Close();
         icmp6.Close();
         exit (1);
     }
     if (setuid(getuid()) < 0) {
-        int xerrno = errno;
-        debugs(42, DBG_CRITICAL, "FATAL: pinger: setuid(" << getuid() << ") failed: " << xstrerr(xerrno));
+        debugs(42, DBG_CRITICAL, "FATAL: pinger: setuid(" << getuid() << ") failed: " << xstrerror());
         icmp4.Close();
         icmp6.Close();
         exit (1);
     }
 
-#if USE_LIBCAP
-    // Drop remaining capabilities (if installed as non-setuid setcap cap_net_raw=ep).
-    // If pinger binary was installed setuid root, setuid() above already dropped all
-    // capabilities, and this is no-op.
-    cap_t caps;
-    caps = cap_init();
-    if (!caps) {
-        int xerrno = errno;
-        debugs(42, DBG_CRITICAL, "FATAL: pinger: cap_init() failed: " << xstrerr(xerrno));
-        icmp4.Close();
-        icmp6.Close();
-        exit (1);
-    } else {
-        if (cap_set_proc(caps) != 0) {
-            int xerrno = errno;
-            // cap_set_proc(cap_init()) is expected to never fail
-            debugs(42, DBG_CRITICAL, "FATAL: pinger: cap_set_proc(none) failed: " << xstrerr(xerrno));
-            cap_free(caps);
-            icmp4.Close();
-            icmp6.Close();
-            exit (1);
-        }
-        cap_free(caps);
-    }
-#endif
-
     last_check_time = squid_curtime;
 
     for (;;) {
@@ -216,12 +210,11 @@ main(int argc, char *argv[])
         }
 
         FD_SET(squid_link, &R);
-        x = select(max_fd+1, &R, NULL, NULL, &tv);
+        x = select(10, &R, NULL, NULL, &tv);
         getCurrentTime();
 
         if (x < 0) {
-            int xerrno = errno;
-            debugs(42, DBG_CRITICAL, HERE << " FATAL Shutdown. select()==" << x << ", ERR: " << xstrerr(xerrno));
+            debugs(42, DBG_CRITICAL, HERE << " FATAL Shutdown. select()==" << x << ", ERR: " << xstrerror());
             control.Close();
             exit(1);
         }
@@ -252,15 +245,13 @@ main(int argc, char *argv[])
     return 0;
 }
 
-#else /* !USE_ICMP */
-
-#include <ostream>
+#else
+#include <stdio.h>
 int
 main(int argc, char *argv[])
 {
-    std::cerr << argv[0] << ": ICMP support not compiled in." << std::endl;
+    fprintf(stderr, "%s: ICMP support not compiled in.\n", argv[0]);
     return 1;
 }
 
 #endif /* USE_ICMP */
-
